@@ -1,8 +1,8 @@
 import unittest
 from os import path
 import sys
-sys.path.append(path.abspath(path.dirname(path.dirname(__file__))))
-sys.path.append(path.abspath(path.dirname(path.dirname(__file__)))+'/src')
+# sys.path.append(path.abspath(path.dirname(path.dirname(__file__))))
+
 from usageFinderTest import KeywordUsageFinderTest, VariableUsageFinderTest
 from testDataDependencyBuilderTest import TestDataDependencyBuilderTest
 from referencesMethodsTest import ReferencesMethodsTest
